<script>
    $(function() {

        var plot;
        var placeholder = $('#charts');
        var datasets = {
            "parsed_links": {
                label: "Updated Backlinks",
                data: <?php echo json_encode($charts['links_on_start'])?>
            },
            "backlinks": {
                label: "Total Backlinks Found",
                data: <?php echo json_encode($charts['links'])?>
            },
            "ratio": {
                label: 'Nofollow Count in %',
                data: <?php echo json_encode($charts['ratio'])?>
            }
        };

        var options = {
            yaxis: {
                min: 0
            },
            xaxis: {
                tickDecimals: 0,
                mode: 'time',
                timeformat: "%d %b %Y %H:%M"
            },
            series: {
                lines: {
                    show: true
                },
                points: {
                    show: true
                }
            },
            grid: {
                hoverable: true,
                clickable: true
            },
            legend : {
                position: "se"
            },
            pan: {
                interactive: true
            }


        };

        // hard-code color indices to prevent them from shifting as
        // countries are turned on/off

        var i = 0;
        $.each(datasets, function(key, val) {
            val.color = i;
            i = i+6;
        });

        // insert checkboxes
        var choiceContainer = $("#choices");
        $.each(datasets, function(key, val) {
            choiceContainer.append("<br/><input type='checkbox' name='" + key +
                "' checked='checked' id='id" + key + "'></input> "
                + val.label );
        });

        choiceContainer.find("input").click(plotAccordingToChoices);

        function plotAccordingToChoices() {

            var data = [];


            choiceContainer.find("input:checked").each(function () {
                var key = $(this).attr("name");
                if (key && datasets[key]) {
                    data.push(datasets[key]);
                }
            });

            if (data.length > 0) {
                plot = $.plot("#charts", data, options);

                $("#charts").bind("plotselected", function (event, ranges) {

                    plot = $.plot($(this), data, $.extend(true, {}, options, {
                        xaxis: {
                            min: ranges.xaxis.from,
                            max: ranges.xaxis.to
                        }
                    }));

                });

            }

        }

        $("<div id='tooltip'></div>").css({
            position: "absolute",
            display: "none",
            border: "1px solid #fdd",
            padding: "2px",
            "background-color": "#fee",
            opacity: 0.80
        }).appendTo("body");

        $(window).resize(function(){
            plotAccordingToChoices();
        })

        plotAccordingToChoices();

        // Add the Flot version string to the footer

        $("#charts").bind("plothover", function (event, pos, item) {

            if (item) {
                var x = item.datapoint[0],
                    y = item.datapoint[1].toFixed(2);
                var newDate = new Date();
                newDate.setTime(x);
                $("#tooltip").html('<b>' + newDate.toUTCString()  + '</b>' + ' ' + item.series.label +  ' <b>' + y + '</b>')
                    .css({top: item.pageY+5, left: item.pageX+5, 'background-color': item.series.color})
                    .fadeIn(200);
            } else {
                $("#tooltip").hide();
            }

        });



    });
</script>
<?php
/**@var $project \App\Model\Project */
?>
<div class = "row">
    <div class="span8">
        <div class="widget">
            <div class="widget-header">
                <i class="icon-bar-chart"></i>
                <h3>Statistics</h3>
            </div>
            <!-- /widget-header -->
            <div class="widget-content">
                <div id="charts"  class = "span6" style="height: 400px"></div>
                <div class = "span3">
                    <div id="choices"></div>
                </div>
            </div>
            <!-- /widget-content -->
        </div>
    </div>
    <div class = "span4">
        <div class="widget">
            <div class="widget-header">
                <i class="icon-bar-chart"></i>
                <h3>Project Overview</h3>
            </div>
            <?php
            $lastParser = $project->getLastParser();
            ?>
            <!-- /widget-header -->
            <div class="widget-content basic-info">
                <dl class="dl-horizontal">
                    <dt>Total Backlinks</dt>
                    <dd><?php echo count($project->ownBacklinks); ?></dd>
                    <?php if ($lastParser):?>
                        <dt>Already Updated</dt>
                        <dd><?php $parsedCount = $project->getLastParser()->getParsedCount(); echo  $parsedCount;?></dd>
                        <dt>Last Update Status</dt>
                        <dd><?php echo $lastParser->getStatus(); ?></dd>
                    <?php else:?>
                        <dt><span class = "error">No Updates Made So Far</span></dt>
                    <?php endif;?>
                </dl>
                <?php if ($lastParser && $lastParser->getStatus() === \App\Model\Parser::STATUS_FINISH && \R::findOne('backlinks', 'projects_id = 1 AND parser_id IS NULL')):?>
                    <?php if($lastParser->can_update):?>
                        <span class = "note-parser-restart">New backlinks was added when parser has been finished.
                    You can update them in last parser or start new parser in <a href = "<?php echo PROJECT_FOLDER;?>project/1/parser">parser menu</a> or by cron.</span>
                        <form method="post" action="<?php echo PROJECT_FOLDER;?>project/1/parser/update"><button class = "btn-success btn">Restart</button></form>
                    <?php else:?>
                        <span class = "note-parser-restart">
                            New links has bean added, but you can't update them, because some links has been removed and it will damage statistics.
                        </span>
                    <?php endif;?>
                <?php endif;?>
            </div>
            <!-- /widget-content -->
        </div>
    </div>
</div>

<!-- /row -->
